/*
Example for Led_Driver Click

    Date          : Jul 2017.
    Author        : Djordje Rosic

Test configuration AVR :
    
    MCU             : ATMEGA32
    Dev. Board      : EasyAVR v7 
    SW              : mikroC PRO for AVR v7.0.0

Description :

   Place the LED driver click in mikroBus socket 1
   This example shows basic control of light brightness with PWM
   Duty cycle is controlled with potentiometer P3
   Jumper J4 needs to be set on A6

*/

#include <stdint.h>

uint16_t currentDuty;

void systemInit()
{
    ADC_Init(); // ADC Init
    PWM16bit_Init(_PWM16_PHASE_CORRECT_MODE_8BIT, _PWM16_PRESCALER_16bit_8, _PWM16_NON_INVERTED, 255, 1);  // PWM Init
    PWM16bit_Start(_TIMER1);
    PWM16bit_Change_Duty(currentDuty, _TIMER1_CH_B);

    Delay_ms(100);

    currentDuty = 0; // Initial value for current duty
}


void main()
{
    systemInit();
    DDA6_bit = 0;                      // Set PORTA pin 6 as input pin for ADC
    DDD4_bit = 1;                      // Set PORTD pin 4 as output pin for PWM

    while( 1 )
    {
        uint8_t cur_duty_byte;

        // Read 10 - bit ADC value and set newly acquired 8 - bit PWM duty
        currentDuty = ADC_Read(6) & 0x0000FFFF;
        currentDuty = currentDuty / 4 ;
        PWM16bit_Change_Duty(currentDuty, _TIMER1_CH_B);     // Set newly acquired duty
    }
}